@@ -3,7 +3,7 @@ export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bi
 echo 'name: yesod-default
 version: 1.2.0
 id: yesod-default-1.2.0-5d724e6255914e391bee90b30a4cef13
-key: yesod_BMKOdQfCdVNACi3s9wq8V1
+key: yesod_L0IStDyJeZu6dJskngLEiP
 license: MIT
 maintainer: Patrick Brisbin <pbrisbin@gmail.com>
 stability: Stable
@@ -21,10 +21,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-default-1.2.0
-hs-libraries: HSyesod-default-1.2.0-BMKOdQfCdVNACi3s9wq8V1
+hs-libraries: HSyesod-default-1.2.0-L0IStDyJeZu6dJskngLEiP
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    yesod-core-1.4.19-69419c3f231fe1a580adea646932aded
+    yesod-core-1.4.19-ac3f1cf7050a843b1fae43913e33aa84
 haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
 haddock-html: /usr/share/doc/haskell-yesod-default/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
